# Reference Observations

Package for importing reference data into the Solar Forecast Arbiter.

This package serves two purposes:

- Creating reference metadata objects.
  - Any sites found in an observation network and their associated Observations and available metadata.
- Importing reference measurements
  - Interacting with a network's API to import the appropriate data as it becomes available.
